/****************************************************************************
**
** This file is part of PLCEdit, an open-source cross-platform editor 
** for PLC source files (e.g. from Moeller, CoDeSys and Siemens).
** Copyright (C) 2005-2009  M. Rehfeldt
**
** This software uses classes of Trolltech Qt toolkit and is freeware. 
** This file may be used under the terms of the GNU General Public License 
** version 2.0 or (at your option) any later version as published by the 
** Free Software Foundation and appearing in the file LICENSE.GPL included 
** in the packaging of this file. 
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** Contact e-mail: M. Rehfeldt <info@plcedit.org>
** Program URL   : http://www.plcedit.org
**
****************************************************************************/


#include "printprepare.h"
#include "pagectrl.h"
#include "prototype.h"


PrintPrepare::PrintPrepare(PageCtrl *pageCtrl, Prototype *prototype)
  : m_PageCtrl(pageCtrl), m_Prototype(prototype) //m_PageCtrl as member VAR of PrefDialog
{ //! creating function
  //! \param PageCtrl class, Protoype class

}


PrintPrepare::~PrintPrepare()
{ //! virtual destructor
}


void PrintPrepare::prepareCurrentPage(QStringList *printList)
{ //! print content of current page

  //clear printList
  printList->clear();
  
  //insert path
  if (!m_PageCtrl->currentFilePath().isEmpty())
    printList->append("\n" + m_PageCtrl->currentFilePath() + "\n");
  
  //printing POUI is not correct: needs to be striped, so that only POUI Dialog field will be printed!
  if (printPOUI == true)
  { //get POU Info section
    printList->append("\n\n");
    //set delimiter
    printList->append("-----------------------------------------------------------------------------\n");
    printList->append(tr("POU Info section") + "\n");
    printList->append("-----------------------------------------------------------------------------\n\n");
    //get POU Info data
    if ((m_PageCtrl->currentFileExt() == 1) || (m_PageCtrl->currentFileExt() == 2))
      printList->append(m_PageCtrl->currentKMHeader());  
    if ((m_PageCtrl->currentFileExt() == 6) || (m_PageCtrl->currentFileExt() == 7))
      printList->append(m_PageCtrl->currentKWDescription());
  }
  
  if (printPrototype == true)
  { //get prototype section
    printList->append("\n\n");
    //set delimiter
    printList->append("-----------------------------------------------------------------------------\n");
    printList->append(tr("Prototype section") + "\n");
    printList->append("-----------------------------------------------------------------------------\n\n");
    //get prototype data
    m_Prototype->currentPrototype(printList); 
  }
  
  if (printDeclarations == true)
  { //get declaration section
    printList->append("\n\n");
    //set delimiter
    printList->append("-----------------------------------------------------------------------------\n");
    printList->append(tr("Declaration section") + "\n");
    printList->append("-----------------------------------------------------------------------------\n\n");
    //get declaration data
    printList->append(m_PageCtrl->currentDeclaration()); 
  }

  if (!(m_PageCtrl->currentFileType().contains("GLOBAL_VARIABLE_LIST")) && (printInstructions == true))
  { //get instruction section
    printList->append("\n\n");
    //set delimiter
    printList->append("-----------------------------------------------------------------------------\n");
    printList->append(tr("Instruction section") + "\n");
    printList->append("-----------------------------------------------------------------------------\n\n");
    //get instruction data
    printList->append(m_PageCtrl->currentInstruction());  
  }
}
